import pytest
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_types.nren_l3_core_service import NRENL3CoreService, NRENL3CoreServiceType
from test.workflows import assert_complete, run_workflow


@pytest.mark.parametrize(
    "l3_core_service_type", [NRENL3CoreServiceType.IMPORTED_GEANT_IP, NRENL3CoreServiceType.IMPORTED_IAS]
)
@pytest.mark.workflow()
def test_import_nren_l3_core_service_success(nren_l3_core_service_subscription_factory, l3_core_service_type):
    imported_nren_l3_core_service = nren_l3_core_service_subscription_factory(
        nren_l3_core_service_type=l3_core_service_type
    )
    result, _, _ = run_workflow("import_nren_l3_core_service", [{"subscription_id": imported_nren_l3_core_service}])
    subscription = NRENL3CoreService.from_subscription(imported_nren_l3_core_service)

    assert_complete(result)
    #  Remove the "IMPORTED_" prefix with ``[9:]``
    assert subscription.nren_l3_core_service_type == NRENL3CoreServiceType(l3_core_service_type.value[9:])
    assert subscription.status == SubscriptionLifecycle.ACTIVE
    assert subscription.insync is True
